=========================
Advanced Usage & Features
=========================

.. toctree::
   :maxdepth: 1

   Dependency Management <dependencies>
   Migrating to Snek <migration>
   Updating your Project's Scaffold <updating>
   Extending Snek <extensions>
